@@ -1,4 +1,4 @@
-# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/LinearStripes.pm 66974 2008-07-25T07:12:29.139681Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Google-Chart/branches/moose/lib/Google/Chart/Fill/LinearStripes.pm 67427 2008-07-29T10:40:51.707813Z lopnor  $
 
 package Google::Chart::Fill::LinearStripes;
 use Moose;
@@ -74,7 +74,7 @@ subtype 'Google::Chart::Fill::LinearStripes::Stripe::Width'
 
 has 'color' => (
     is => 'rw',
-    isa => 'Google::Chart::Color',
+    isa => 'Google::Chart::Color::Data',
     required => 1
 );
 
